@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.datastream_v1alpha1.services.datastream import pagers
@@ -173,10 +175,10 @@ class DatastreamAsyncClient:
 
     async def list_connection_profiles(
         self,
-        request: datastream.ListConnectionProfilesRequest = None,
+        request: Union[datastream.ListConnectionProfilesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListConnectionProfilesAsyncPager:
@@ -184,7 +186,7 @@ class DatastreamAsyncClient:
         in a project and location.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.ListConnectionProfilesRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.ListConnectionProfilesRequest, dict]):
                 The request object.
             parent (:class:`str`):
                 Required. The parent that owns the
@@ -251,10 +253,10 @@ class DatastreamAsyncClient:
 
     async def get_connection_profile(
         self,
-        request: datastream.GetConnectionProfileRequest = None,
+        request: Union[datastream.GetConnectionProfileRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datastream_resources.ConnectionProfile:
@@ -262,7 +264,7 @@ class DatastreamAsyncClient:
         profile.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.GetConnectionProfileRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.GetConnectionProfileRequest, dict]):
                 The request object.
             name (:class:`str`):
                 Required. The name of the connection
@@ -320,12 +322,12 @@ class DatastreamAsyncClient:
 
     async def create_connection_profile(
         self,
-        request: datastream.CreateConnectionProfileRequest = None,
+        request: Union[datastream.CreateConnectionProfileRequest, dict] = None,
         *,
         parent: str = None,
         connection_profile: datastream_resources.ConnectionProfile = None,
         connection_profile_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -333,7 +335,7 @@ class DatastreamAsyncClient:
         project and location.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.CreateConnectionProfileRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.CreateConnectionProfileRequest, dict]):
                 The request object.
             parent (:class:`str`):
                 Required. The parent that owns the
@@ -421,11 +423,11 @@ class DatastreamAsyncClient:
 
     async def update_connection_profile(
         self,
-        request: datastream.UpdateConnectionProfileRequest = None,
+        request: Union[datastream.UpdateConnectionProfileRequest, dict] = None,
         *,
         connection_profile: datastream_resources.ConnectionProfile = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -433,7 +435,7 @@ class DatastreamAsyncClient:
         connection profile.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.UpdateConnectionProfileRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.UpdateConnectionProfileRequest, dict]):
                 The request object.
             connection_profile (:class:`google.cloud.datastream_v1alpha1.types.ConnectionProfile`):
                 Required. The ConnectionProfile to
@@ -519,17 +521,17 @@ class DatastreamAsyncClient:
 
     async def delete_connection_profile(
         self,
-        request: datastream.DeleteConnectionProfileRequest = None,
+        request: Union[datastream.DeleteConnectionProfileRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Use this method to delete a connection profile..
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.DeleteConnectionProfileRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.DeleteConnectionProfileRequest, dict]):
                 The request object.
             name (:class:`str`):
                 Required. The name of the connection
@@ -610,9 +612,9 @@ class DatastreamAsyncClient:
 
     async def discover_connection_profile(
         self,
-        request: datastream.DiscoverConnectionProfileRequest = None,
+        request: Union[datastream.DiscoverConnectionProfileRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datastream.DiscoverConnectionProfileResponse:
@@ -623,7 +625,7 @@ class DatastreamAsyncClient:
         that's optionally supplied in the request.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.DiscoverConnectionProfileRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.DiscoverConnectionProfileRequest, dict]):
                 The request object. Request message for 'discover'
                 ConnectionProfile request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -661,10 +663,10 @@ class DatastreamAsyncClient:
 
     async def list_streams(
         self,
-        request: datastream.ListStreamsRequest = None,
+        request: Union[datastream.ListStreamsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListStreamsAsyncPager:
@@ -672,7 +674,7 @@ class DatastreamAsyncClient:
         location.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.ListStreamsRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.ListStreamsRequest, dict]):
                 The request object.
             parent (:class:`str`):
                 Required. The parent that owns the
@@ -739,17 +741,17 @@ class DatastreamAsyncClient:
 
     async def get_stream(
         self,
-        request: datastream.GetStreamRequest = None,
+        request: Union[datastream.GetStreamRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datastream_resources.Stream:
         r"""Use this method to get details about a stream.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.GetStreamRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.GetStreamRequest, dict]):
                 The request object.
             name (:class:`str`):
                 Required. The name of the stream
@@ -807,19 +809,19 @@ class DatastreamAsyncClient:
 
     async def create_stream(
         self,
-        request: datastream.CreateStreamRequest = None,
+        request: Union[datastream.CreateStreamRequest, dict] = None,
         *,
         parent: str = None,
         stream: datastream_resources.Stream = None,
         stream_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Use this method to create a stream.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.CreateStreamRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.CreateStreamRequest, dict]):
                 The request object.
             parent (:class:`str`):
                 Required. The parent that owns the
@@ -905,11 +907,11 @@ class DatastreamAsyncClient:
 
     async def update_stream(
         self,
-        request: datastream.UpdateStreamRequest = None,
+        request: Union[datastream.UpdateStreamRequest, dict] = None,
         *,
         stream: datastream_resources.Stream = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -917,7 +919,7 @@ class DatastreamAsyncClient:
         stream.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.UpdateStreamRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.UpdateStreamRequest, dict]):
                 The request object.
             stream (:class:`google.cloud.datastream_v1alpha1.types.Stream`):
                 Required. The stream resource to
@@ -1002,17 +1004,17 @@ class DatastreamAsyncClient:
 
     async def delete_stream(
         self,
-        request: datastream.DeleteStreamRequest = None,
+        request: Union[datastream.DeleteStreamRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Use this method to delete a stream.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.DeleteStreamRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.DeleteStreamRequest, dict]):
                 The request object.
             name (:class:`str`):
                 Required. The name of the stream
@@ -1093,9 +1095,9 @@ class DatastreamAsyncClient:
 
     async def fetch_errors(
         self,
-        request: datastream.FetchErrorsRequest = None,
+        request: Union[datastream.FetchErrorsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1103,7 +1105,7 @@ class DatastreamAsyncClient:
         stream.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.FetchErrorsRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.FetchErrorsRequest, dict]):
                 The request object. Request message for 'FetchErrors'
                 request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1154,10 +1156,10 @@ class DatastreamAsyncClient:
 
     async def fetch_static_ips(
         self,
-        request: datastream.FetchStaticIpsRequest = None,
+        request: Union[datastream.FetchStaticIpsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.FetchStaticIpsAsyncPager:
@@ -1167,7 +1169,7 @@ class DatastreamAsyncClient:
         optionally supplied in the request.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.FetchStaticIpsRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.FetchStaticIpsRequest, dict]):
                 The request object. Request message for 'FetchStaticIps'
                 request.
             name (:class:`str`):
@@ -1237,12 +1239,12 @@ class DatastreamAsyncClient:
 
     async def create_private_connection(
         self,
-        request: datastream.CreatePrivateConnectionRequest = None,
+        request: Union[datastream.CreatePrivateConnectionRequest, dict] = None,
         *,
         parent: str = None,
         private_connection: datastream_resources.PrivateConnection = None,
         private_connection_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1250,7 +1252,7 @@ class DatastreamAsyncClient:
         configuration.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.CreatePrivateConnectionRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.CreatePrivateConnectionRequest, dict]):
                 The request object.
             parent (:class:`str`):
                 Required. The parent that owns the
@@ -1338,10 +1340,10 @@ class DatastreamAsyncClient:
 
     async def get_private_connection(
         self,
-        request: datastream.GetPrivateConnectionRequest = None,
+        request: Union[datastream.GetPrivateConnectionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datastream_resources.PrivateConnection:
@@ -1349,7 +1351,7 @@ class DatastreamAsyncClient:
         connectivity configuration.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.GetPrivateConnectionRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.GetPrivateConnectionRequest, dict]):
                 The request object.
             name (:class:`str`):
                 Required. The name of the  private
@@ -1411,10 +1413,10 @@ class DatastreamAsyncClient:
 
     async def list_private_connections(
         self,
-        request: datastream.ListPrivateConnectionsRequest = None,
+        request: Union[datastream.ListPrivateConnectionsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPrivateConnectionsAsyncPager:
@@ -1422,7 +1424,7 @@ class DatastreamAsyncClient:
         configurations in a project and location.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.ListPrivateConnectionsRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.ListPrivateConnectionsRequest, dict]):
                 The request object.
             parent (:class:`str`):
                 Required. The parent that owns the
@@ -1490,10 +1492,10 @@ class DatastreamAsyncClient:
 
     async def delete_private_connection(
         self,
-        request: datastream.DeletePrivateConnectionRequest = None,
+        request: Union[datastream.DeletePrivateConnectionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1501,7 +1503,7 @@ class DatastreamAsyncClient:
         configuration.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.DeletePrivateConnectionRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.DeletePrivateConnectionRequest, dict]):
                 The request object.
             name (:class:`str`):
                 Required. The name of the private
@@ -1582,12 +1584,12 @@ class DatastreamAsyncClient:
 
     async def create_route(
         self,
-        request: datastream.CreateRouteRequest = None,
+        request: Union[datastream.CreateRouteRequest, dict] = None,
         *,
         parent: str = None,
         route: datastream_resources.Route = None,
         route_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1595,7 +1597,7 @@ class DatastreamAsyncClient:
         connectivity in a project and location.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.CreateRouteRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.CreateRouteRequest, dict]):
                 The request object. route creation request
             parent (:class:`str`):
                 Required. The parent that owns the
@@ -1682,17 +1684,17 @@ class DatastreamAsyncClient:
 
     async def get_route(
         self,
-        request: datastream.GetRouteRequest = None,
+        request: Union[datastream.GetRouteRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datastream_resources.Route:
         r"""Use this method to get details about a route.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.GetRouteRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.GetRouteRequest, dict]):
                 The request object. route get request
             name (:class:`str`):
                 Required. The name of the Route
@@ -1754,10 +1756,10 @@ class DatastreamAsyncClient:
 
     async def list_routes(
         self,
-        request: datastream.ListRoutesRequest = None,
+        request: Union[datastream.ListRoutesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListRoutesAsyncPager:
@@ -1765,7 +1767,7 @@ class DatastreamAsyncClient:
         connectivity in a project and location.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.ListRoutesRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.ListRoutesRequest, dict]):
                 The request object. route list request
             parent (:class:`str`):
                 Required. The parent that owns the
@@ -1833,17 +1835,17 @@ class DatastreamAsyncClient:
 
     async def delete_route(
         self,
-        request: datastream.DeleteRouteRequest = None,
+        request: Union[datastream.DeleteRouteRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Use this method to delete a route.
 
         Args:
-            request (:class:`google.cloud.datastream_v1alpha1.types.DeleteRouteRequest`):
+            request (Union[google.cloud.datastream_v1alpha1.types.DeleteRouteRequest, dict]):
                 The request object. route deletion request
             name (:class:`str`):
                 Required. The name of the Route
