@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.datastream_v1alpha1.types import datastream
@@ -75,14 +75,14 @@ class ListConnectionProfilesPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datastream.ListConnectionProfilesResponse]:
+    def pages(self) -> Iterator[datastream.ListConnectionProfilesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[datastream_resources.ConnectionProfile]:
+    def __iter__(self) -> Iterator[datastream_resources.ConnectionProfile]:
         for page in self.pages:
             yield from page.connection_profiles
 
@@ -137,14 +137,14 @@ class ListConnectionProfilesAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datastream.ListConnectionProfilesResponse]:
+    async def pages(self) -> AsyncIterator[datastream.ListConnectionProfilesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[datastream_resources.ConnectionProfile]:
+    def __aiter__(self) -> AsyncIterator[datastream_resources.ConnectionProfile]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.connection_profiles:
@@ -203,14 +203,14 @@ class ListStreamsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datastream.ListStreamsResponse]:
+    def pages(self) -> Iterator[datastream.ListStreamsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[datastream_resources.Stream]:
+    def __iter__(self) -> Iterator[datastream_resources.Stream]:
         for page in self.pages:
             yield from page.streams
 
@@ -265,14 +265,14 @@ class ListStreamsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datastream.ListStreamsResponse]:
+    async def pages(self) -> AsyncIterator[datastream.ListStreamsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[datastream_resources.Stream]:
+    def __aiter__(self) -> AsyncIterator[datastream_resources.Stream]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.streams:
@@ -331,14 +331,14 @@ class FetchStaticIpsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datastream.FetchStaticIpsResponse]:
+    def pages(self) -> Iterator[datastream.FetchStaticIpsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[str]:
+    def __iter__(self) -> Iterator[str]:
         for page in self.pages:
             yield from page.static_ips
 
@@ -393,14 +393,14 @@ class FetchStaticIpsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datastream.FetchStaticIpsResponse]:
+    async def pages(self) -> AsyncIterator[datastream.FetchStaticIpsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[str]:
+    def __aiter__(self) -> AsyncIterator[str]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.static_ips:
@@ -459,14 +459,14 @@ class ListPrivateConnectionsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datastream.ListPrivateConnectionsResponse]:
+    def pages(self) -> Iterator[datastream.ListPrivateConnectionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[datastream_resources.PrivateConnection]:
+    def __iter__(self) -> Iterator[datastream_resources.PrivateConnection]:
         for page in self.pages:
             yield from page.private_connections
 
@@ -521,14 +521,14 @@ class ListPrivateConnectionsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datastream.ListPrivateConnectionsResponse]:
+    async def pages(self) -> AsyncIterator[datastream.ListPrivateConnectionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[datastream_resources.PrivateConnection]:
+    def __aiter__(self) -> AsyncIterator[datastream_resources.PrivateConnection]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.private_connections:
@@ -587,14 +587,14 @@ class ListRoutesPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datastream.ListRoutesResponse]:
+    def pages(self) -> Iterator[datastream.ListRoutesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[datastream_resources.Route]:
+    def __iter__(self) -> Iterator[datastream_resources.Route]:
         for page in self.pages:
             yield from page.routes
 
@@ -649,14 +649,14 @@ class ListRoutesAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datastream.ListRoutesResponse]:
+    async def pages(self) -> AsyncIterator[datastream.ListRoutesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[datastream_resources.Route]:
+    def __aiter__(self) -> AsyncIterator[datastream_resources.Route]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.routes:
